==> react-native-ui-xep-0.1.28.tgz: package/src/atoms/MultiSelect/MultiSelectDropDown.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { styles } from './MutlitSelectStyles';
import { Item, Label, NativeBase, Text, View } from 'native-base';
import { ScrollView, TouchableOpacity } from 'react-native';
import Icon from 'react-native-vector-icons/AntDesign';
import { SelectSearchBar } from './SelectSearchBar';

export type ItemProp = { label: string; value: string; isSelected?: boolean };
export type MultiSelectTagDropDownProps = {
  type: 'bordered' | 'primary';
  pickerList: ItemProp[];
  label?: string;
  labelProps?: NativeBase.Label;
  onChange: (val: string[]) => void;
  placeholder?: string;
  validationInfo?: string[];
  tagColor?: string;
  value?: string[];
};
export const MultiSelectDropDown: FC<MultiSelectTagDropDownProps> = (
  props: MultiSelectTagDropDownProps
) => {
  const {
    label,
    labelProps,
    pickerList,
    onChange,
    validationInfo,
    placeholder,
    value,
    type,
    tagColor,
  } = props;
  const [showPickerList, setShowPickerList] = useState<boolean>(false);
  const [pickedList, setPickedList] = useState<ItemProp[]>([]);
  const [dataList, setDataList] = useState<ItemProp[]>([]);
  useEffect(() => {
    setDataList(pickerList);
  }, [pickerList]);
  const onSelect = (value: ItemProp, selected: boolean) => {
    const index = dataList.findIndex((value1) => value1.value === value.value);
    const temp = dataList.slice();
    temp[index] = { ...value, isSelected: selected };
    setDataList(temp);
  };
  const removeItem = (val: ItemProp) => {
    const temp = pickedList.filter((item) => item.value !== val.value);
    onSelect(val, false);
    setPickedList(temp);
    onChange(temp.map((item) => item.value));
  };
  const renderTags = () => {
    if (pickedList.length === 0) {
      return (
        <Text style={{ marginTop: 5, marginBottom: 5, color: '#C4C4C4' }}>
          {placeholder ?? 'Click to select'}
        </Text>
      );
    }
    return pickedList.map((item, index) => {
      return (
        <View
          style={[
            styles.tagContainer,
            { backgroundColor: tagColor ?? '#FD8282' },
          ]}
          key={index}
        >
          <Text
            style={{ marginRight: 5, color: 'white' }}
            numberOfLines={1}
            onPress={() => setShowPickerList(!showPickerList)}
          >
            {item.label}
          </Text>
          <TouchableOpacity
            style={{ paddingLeft: 20, paddingRight: 20 }}
            onPress={() => removeItem(item)}
          >
            <Icon
              style={{ color: 'white', fontSize: 15 }}
              name={'closecircleo'}
            />
          </TouchableOpacity>
        </View>
      );
    });
  };
  const onComplete = (val: ItemProp[]) => {
    setPickedList(val);
    onChange(val.map((item) => item.value));
  };
  useEffect(() => {
    if (value && value.length > 0) {
      const temp = pickerList.filter((item) => value.includes(item.value));
      setPickedList(temp);
      const tem = pickerList.slice();
      for (const val of value) {
        const ind = tem.findIndex((itm) => itm.value === val);
        tem[ind] = { ...tem[ind], isSelected: true };
      }
      setDataList(tem);
    }
  }, [pickerList, value]);
  const renderElement = (selectStyleX?: any, labelStyle?: any) => {
    return (
      <Item stackedLabel={label !== undefined} style={styles.itemStyle}>
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps?.style as object) }
                : labelStyle
            }
          >
            {label}
            {'   '}
            {validationInfo && validationInfo?.length > 0 && (
              <Text style={{ color: '#f39c12', marginLeft: 5 }}>
                {validationInfo}
              </Text>
            )}
          </Label>
        )}
        {pickedList.length === 0 ? (
          <TouchableOpacity
            style={styles.default}
            onPress={() => setShowPickerList(!showPickerList)}
          >
            <View style={[selectStyleX, { padding: 8 }]}>{renderTags()}</View>
          </TouchableOpacity>
        ) : (
          <TouchableOpacity
            // style={{ width: '100%', backgroundColor: 'blue'}}
            onPress={() => setShowPickerList(!showPickerList)}
          >
            <View
              style={[
                styles.default,
                selectStyleX,
                { flexDirection: 'row', padding: 6 },
              ]}
              onStartShouldSetResponder={() => true}
            >
              <ScrollView horizontal={true}>
                <TouchableOpacity
                  style={{
                    alignSelf: 'stretch',
                    flexDirection: 'row',
                  }}
                  onPress={() => setShowPickerList(!showPickerList)}
                >
                  {renderTags()}
                </TouchableOpacity>
                <Text
                  style={[
                    {
                      alignSelf: 'stretch',
                      color: 'transparent',
                    },
                  ]}
                  onPress={() => setShowPickerList(!showPickerList)}
                >
                  {' '}
                  ************* **********
                </Text>
              </ScrollView>
            </View>
          </TouchableOpacity>
        )}
        <SelectSearchBar
          onSelect={onSelect}
          onComplete={onComplete}
          data={dataList}
          showModal={showPickerList}
          closeModal={() => setShowPickerList(false)}
          value={pickedList}
        />
      </Item>
    );
  };
  switch (type) {
    case 'bordered':
      return renderElement(
        { ...styles.bordered },
        {
          ...styles.textDefault,
          color: '#979797',
        }
      );
    default:
      return renderElement(styles.multiSelect, styles.textDefault);
  }
};

==> react-native-ui-xep-0.1.34.tgz: package/src/atoms/MultiSelect/MultiSelectDropDown.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { styles } from './MutlitSelectStyles';
import { Item, Label, NativeBase, Text, View } from 'native-base';
import { ScrollView, TouchableOpacity } from 'react-native';
import Icon from 'react-native-vector-icons/AntDesign';
import { SelectSearchBar } from './SelectSearchBar';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';

export type ItemProp = { label: string; value: string; isSelected?: boolean };
export type MultiSelectTagDropDownProps = {
  type: 'bordered' | 'primary';
  pickerList: ItemProp[];
  label?: string;
  labelProps?: NativeBase.Label;
  onChange: (val: string[]) => void;
  placeholder?: string;
  validationInfo?: string[];
  tagColor?: string;
  value?: string[];
};
export const MultiSelectDropDown: FC<MultiSelectTagDropDownProps> = (
  props: MultiSelectTagDropDownProps
) => {
  const {
    label,
    labelProps,
    pickerList,
    onChange,
    placeholder,
    value,
    type,
    tagColor,
  } = props;
  const [showPickerList, setShowPickerList] = useState<boolean>(false);
  const [pickedList, setPickedList] = useState<ItemProp[]>([]);
  const [dataList, setDataList] = useState<ItemProp[]>([]);
  useEffect(() => {
    setDataList(pickerList);
  }, [pickerList]);
  const onSelect = (value: ItemProp, selected: boolean) => {
    const index = dataList.findIndex((value1) => value1.value === value.value);
    const temp = dataList.slice();
    temp[index] = { ...value, isSelected: selected };
    setDataList(temp);
  };
  const removeItem = (val: ItemProp) => {
    const temp = pickedList.filter((item) => item.value !== val.value);
    onSelect(val, false);
    setPickedList(temp);
    onChange(temp.map((item) => item.value));
  };
  const renderTags = (placeholderColor?: string) => {
    if (pickedList.length === 0) {
      return (
        <Text
          style={{
            marginTop: 5,
            marginBottom: 5,
            color: placeholderColor ?? '#C4C4C4',
          }}
        >
          {placeholder ?? 'Click to select'}
        </Text>
      );
    }
    return pickedList.map((item, index) => {
      return (
        <View
          style={[
            styles.tagContainer,
            { backgroundColor: tagColor ?? '#FD8282' },
          ]}
          key={index}
        >
          <Text
            style={{ marginRight: 5, color: 'white' }}
            numberOfLines={1}
            onPress={() => setShowPickerList(!showPickerList)}
          >
            {item.label}
          </Text>
          <TouchableOpacity
            style={{ paddingLeft: 20, paddingRight: 20 }}
            onPress={() => removeItem(item)}
          >
            <Icon
              style={{ color: 'white', fontSize: 15 }}
              name={'closecircleo'}
            />
          </TouchableOpacity>
        </View>
      );
    });
  };
  const onComplete = (val: ItemProp[]) => {
    setPickedList(val);
    onChange(val.map((item) => item.value));
  };
  useEffect(() => {
    if (value && value.length > 0) {
      const temp = pickerList.filter((item) => value.includes(item.value));
      setPickedList(temp);
      const tem = pickerList.slice();
      for (const val of value) {
        const ind = tem.findIndex((itm) => itm.value === val);
        tem[ind] = { ...tem[ind], isSelected: true };
      }
      setDataList(tem);
    }
  }, [pickerList, value]);
  const renderElement = (
    selectStyleX?: any,
    labelStyle?: any,
    placeholderColor?: string
  ) => {
    return (
      <Item stackedLabel={label !== undefined} style={styles.itemStyle}>
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps?.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}
        {pickedList.length === 0 ? (
          <TouchableOpacity
            style={styles.default}
            onPress={() => setShowPickerList(!showPickerList)}
          >
            <View style={[selectStyleX, { padding: 8 }]}>{renderTags(placeholderColor)}</View>
          </TouchableOpacity>
        ) : (
          <TouchableOpacity
            // style={{ width: '100%', backgroundColor: 'blue'}}
            onPress={() => setShowPickerList(!showPickerList)}
          >
            <View
              style={[
                styles.default,
                selectStyleX,
                { flexDirection: 'row', padding: 6 },
              ]}
              onStartShouldSetResponder={() => true}
            >
              <ScrollView horizontal={true}>
                <TouchableOpacity
                  style={{
                    alignSelf: 'stretch',
                    flexDirection: 'row',
                  }}
                  onPress={() => setShowPickerList(!showPickerList)}
                >
                  {renderTags(placeholderColor)}
                </TouchableOpacity>
                <Text
                  style={[
                    {
                      alignSelf: 'stretch',
                      color: 'transparent',
                    },
                  ]}
                  onPress={() => setShowPickerList(!showPickerList)}
                >
                  {' '}
                  ************* **********
                </Text>
              </ScrollView>
            </View>
          </TouchableOpacity>
        )}
        <SelectSearchBar
          onSelect={onSelect}
          onComplete={onComplete}
          data={dataList}
          showModal={showPickerList}
          closeModal={() => setShowPickerList(false)}
          value={pickedList}
        />
      </Item>
    );
  };
  switch (type) {
    case 'bordered':
      return renderElement(
        { ...styles.bordered },
        {
          ...styles.textDefault,
          color: borderedInputVariables.labelColor,
          marginLeft: 10,
          fontWeight: 'bold',
        },
        borderedInputVariables.placeholderColor
      );
    default:
      return renderElement(
        styles.multiSelect,
        styles.textDefault,
        primaryInputVariables.placeholderColor
      );
  }
};
